# Shell  |  Copyright(C), 2004-5, Enfold Systems, LLC
#
# Enfold Systems, LLC
# 4617 Montrose Blvd., Suite C215
# Houston, Texas 77006 USA
# p. +1 713.942.2377 | f. +1 832.201.8856
# www.enfoldsystems.com
# info@enfoldsystems.com
#
#
# This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.

VERSION = "0.2"

from wx.py.shell import Shell
from wx.py.shell import ShellFrame
from wx.py import frame
import wx

import os, sys

class MyFrame(ShellFrame):
    """Wrapper"""
    def __init__(self, parent=None, id=-1, title='PloneShell',
                 pos=wx.DefaultPosition, size=wx.DefaultSize,
                 style=wx.DEFAULT_FRAME_STYLE, locals=None,
                 InterpClass=None, *args, **kwds):
        """ A wrapper around the ShellFrame, which is hard to change """
        frame.Frame.__init__(self, parent, id, title, pos, size, style)
        intro_text = """Plone Interactive Shell
Copyright Enfold Systems, 2004-5. Based on PyShell.
Notes:
    app: mapped to server application object
    admin: mapped to admin tools"""
        self.shell = Shell(parent=self, id=-1, introText=intro_text,
                           locals=locals, InterpClass=InterpClass,
                           *args, **kwds)
        # Override the shell so that status messages go to the status bar.
        self.shell.setStatusText = self.SetStatusText

    def OnAbout(self, event):
        """Display an About window."""
        title = 'About PloneShell'
        text = 'PloneShell %s\n\n' % VERSION + \
               'PloneShell, based an PyShell\n\n' + \
               'PloneShell: By Andy McKay, Enfold Systems, LLC\n'+\
               'PyShell: Half-baked by Patrick K. O\'Brien,\n' + \
               'Shell Revision: %s\n' % self.shell.revision + \
               'Interpreter Revision: %s\n\n' % self.shell.interp.revision + \
               'Python Version: %s\n' % sys.version.split()[0] + \
               'wxPython Version: %s\n' % wx.VERSION_STRING + \
               'Platform: %s\n' % sys.platform
        dialog = wx.MessageDialog(self, text, title,
                                  wx.OK | wx.ICON_INFORMATION)
        dialog.ShowModal()
        dialog.Destroy()

class callback:
    def __init__(self, cfg):
        self._cfg = cfg
        self._zapp = None

    def __call__(self):
        cfg = str(self._cfg)
        if os.path.isdir(cfg):
            cfg = os.path.join(cfg, 'etc', 'zope.conf')

        sys.argv = sys.argv[:1]

        try:
            # Zope >= 2.8.x
            import Zope2 as Zope
        except ImportError:
            # Zope < 2.8.x
            import Zope

        from App import FindHomes

        Zope.configure(cfg)

        # pull in zeoTimeOut if available
        try:
            from EnfoldTools.Cluster.util.zeo_time_out import turnOn
            turnOn()
        except ImportError:
            pass

        self._zapp = Zope.app()
        self.db_configure()


        return self._zapp

    def db_configure(self):
        # we can do this because import Zope has done its magic
        from Products.CMFCore.tests.base.security import PermissiveSecurityPolicy
        import AccessControl

        from AccessControl.SecurityManagement import newSecurityManager
        from AccessControl.SecurityManager import setSecurityPolicy
        from Testing.makerequest import makerequest

        _policy = PermissiveSecurityPolicy()
        _oldpolicy = setSecurityPolicy(_policy)

        newSecurityManager(None, AccessControl.User.system)
        self._zapp = makerequest(self._zapp)
